(mission)=

# Mission

```{epigraph}
The core mission of GeoUtils is to be **easy-of-use**, **robust**, **reproducible** and **fully open**.

Additionally, GeoUtils aims to be **efficient**, **scalable** and **state-of-the-art**.
```

In details, those mean:

- **Ease-of-use:** all basic operations or methods only require a few lines of code to be performed;

- **Robustness:** all methods are tested within our continuous integration test-suite, to enforce that they always perform as expected;

- **Reproducibility:** all code is version-controlled and release-based, to ensure consistency of dependent packages and works;

- **Open-source:** all code is accessible and reusable to anyone in the community, for transparency and open governance.

```{note}
:class: margin
Additional mission points, in particular **scalability**, are partly developed with aim of being finalized when our long-term ``v1.0`` is reached.
```

And, additionally:

- **Efficiency**: all methods should be optimized at the lower-level, to function with the highest performance offered by Python packages;

- **Scalability**: all methods should support both lazy processing and distributed parallelized processing, to work with high-resolution data on local machines as well as on HPCs;

- **State-of-the-art**: all methods should be at the cutting edge of remote sensing science, to provide users with the most reliable and up-to-date tools.
